import { Cytoscape, CytoscapeProvider } from './cytoscape-layouts';
import { Graphology, GraphologyProvider } from './graphology-layouts';

export type GraphologyLayoutAlgorithms = `Graphology_circular` | `Graphology_random` | `Graphology_noverlap` | `Graphology_forceAtlas2`;
export type CytoscapeLayoutAlgorithms =
  | 'Cytoscape_klay'
  | 'Cytoscape_dagre'
  | 'Cytoscape_elk'
  | 'Cytoscape_fcose'
  | 'Cytoscape_cose-bilkent'
  | 'Cytoscape_cise';

export type AllLayoutAlgorithms = GraphologyLayoutAlgorithms | CytoscapeLayoutAlgorithms;

export type Providers = GraphologyProvider | CytoscapeProvider;
export type LayoutAlgorithm<Provider extends Providers> = `${Provider}_${string}`;

export type AlgorithmToLayoutProvider<Algorithm extends AllLayoutAlgorithms> = Algorithm extends GraphologyLayoutAlgorithms
  ? Graphology
  : Algorithm extends CytoscapeLayoutAlgorithms
  ? Cytoscape
  : Cytoscape | Graphology;

export enum Layouts {
  KLAY = 'Cytoscape_klay',
  DAGRE = 'Cytoscape_dagre',
  ELK = 'Cytoscape_elk',
  FCOSE = 'Cytoscape_fcose',
  COSE_BILKENT = 'Cytoscape_cose-bilkent',
  CISE = 'Cytoscape_cise',
  RANDOM = 'Graphology_random',
  CIRCULAR = 'Graphology_circular',
  NOVERLAP = 'Graphology_noverlap',
  FORCEATLAS2 = 'Graphology_forceAtlas2',
}
