import React from 'react';
import {MapPanel, LayerPanel} from './components';
import {useGraphQueryResult} from '../../data-access/store';
import GraphModel from './graphModel';
import {GraphType, Layer} from './Types';

export default function MapVis() {
  const [layers, setLayers] = React.useState<Layer[]>([]);
  const [showFilter, setShowFilter] = React.useState<boolean>(false);

  const graphQueryResult = useGraphQueryResult();
  if (!graphQueryResult) return <p>No loading graph data</p>;

  let graph: GraphType | null = null;
  try {
    graph = React.useMemo(() => {
      const graphModel = new GraphModel();
      graphModel.consumeMessageFromBackend(graphQueryResult);
      return graphModel;
    }, [graphQueryResult]);
  } catch (error) {
    return <p>Error creating graph</p>;
  }

  return (
    <div className="flex flex-row justify-between overflow-hidden w-screen h-screen font-sans">
      <MapPanel graph={graph} layers={layers} showFilter={showFilter} setShowFilter={setShowFilter}/>
      <LayerPanel layers={layers} setLayers={setLayers} graphInfo={graph.getGraphInfo()} setShowFilter={setShowFilter}/>
    </div>
  );
}
